@@ -8,7 +8,7 @@ use strict;
 
 package XML::Compile;
 use vars '$VERSION';
-$VERSION = '0.96';
+$VERSION = '0.97';
 
 
 use Log::Report 'xml-compile', syntax => 'SHORT';
@@ -112,9 +112,11 @@ sub dataToXML($)
 
 sub _parsedNode($)
 {   my ($thing, $node) = @_;
+    my $top = $node;
 
     if($node->isa('XML::LibXML::Document'))
-    {   my $eltype = type_of_node($node->documentElement) || '(none)';
+    {   $top       = $node->documentElement;
+        my $eltype = type_of_node($top || '(none)');
         trace "using preparsed XML document with element <$eltype>";
     }
     elsif($node->isa('XML::LibXML::Element'))
@@ -129,9 +131,7 @@ sub _parsedNode($)
           , got => $text;
     }
 
-    ( $node
-    , source => ref $node
-    );
+    ($top, source => ref $node);
 }
 
 sub _parseScalar($)
